@@ -1,7 +1,7 @@
 package Mail::Milter::Authentication::Handler;
 use strict;
 use warnings;
-our $VERSION = '2.20180510'; # VERSION
+our $VERSION = '2.20180511'; # VERSION
 
 use Digest::MD5 qw{ md5_hex };
 use English qw{ -no_match_vars };
@@ -120,7 +120,7 @@ sub is_exception_type {
     return if ! $exception;
     return if ref $exception ne 'Mail::Milter::Authentication::Exception';
     my $Type = $exception->{ 'Type' } || 'Unknown';
-    return 1;
+    return $Type;
 }
 
 sub handle_exception {
@@ -1653,7 +1653,7 @@ Mail::Milter::Authentication::Handler
 
 =head1 VERSION
 
-version 2.20180510
+version 2.20180511
 
 =head1 DESCRIPTION
 
